Unit WDMapi;
{ ========================================================================== }
{ =   Lynx Tecnologia Eletrnica Ltda.                                     = }
{ =   Projeto:   Windows WDM Drivers - CAD12/56         Data: 20/jan/2000  = }
{ =   Programa:  Teste do driver da CAD12/56 para Windows 98.              = }
{ =   Mdulo:    WDMapi                                                    = }
{ =   Autor:     Lauro                                                     = }
{ =   Descrio: Acesso s primitivas da DLL WDM_1256                      = }
{ =   Verso:    2.0                                                       = }
{ ========================================================================== }
{$ALIGN OFF}  { Desliga opo de alinhamento da memria }

{-------------------------  Descrio da Interface  -------------------------}
Interface
  Uses Windows;

{ ===================================================== }
{ =              Declarao de constantes             = }
{ ===================================================== }

  Const {---------------------------------- ieXXXX: Interrupt error status --}
    ieNoError        = 0;   { Nenhum erro }
    ieIntOverrun     = 1;   { Overrun de interrupo }
    ieAD_Error       = 2;   { Erro no conversor A/D }
    ieBufOverrun     = 3;   { Overflow no buffer de aquisio do driver }
    ieDriver         = 100; { Erro de acesso ao driver }
    ieAcqStop        = 101; { Aquisio no est ativa }
    ieBufSize        = 102; { Dimenso errada do buffer }

  Const {------------------ seXXXX: Cdigo de erro da WDM_StartAcquisition --}
    seNoError        = 0;   { Nenhum erro }
    seNoSignal       = 1;   { Nenhum sinal habilitado }


{ ===================================================== }
{ =     Declarao de tipos e variveis pblicas      = }
{ ===================================================== }

  Type {--------------------------- Parmetro de entrada da WDM_DriverInfo --}
    TpAiRange = array [0..15] of single;
    TpDriverInfo = record
      VersionHigh : byte;	{ Verso do driver: nmero da verso }
      VersionLow  : byte;   	{ Verso do driver: nmero da reviso }
      CAD_IoBase  : longint;    { Endereo base da placa }
      CAD_IRQ     : longint;    { Canal de interrupo da placa }
      CAD_DMA     : longint;    { Canal de DMA da placa }
      TmrClock    : single;     { Clock do timer (Hz) }
      nAiChannels : smallint;   { Nmero de entradas analgicas }
      nAiRange    : smallint;   { Nmero de faixas de entrada do A/D }
      AiRange     : TpAiRange;  { Faixas de entrada (volts) }
      nAoChannels : smallint;   { Nmero de sadas analgica }
      nDiPorts    : smallint;   { Nmero de ports de entrada digital }
      nBitsDI     : smallint;   { Nmero de bits por port de entrada digital }
      nDoPorts    : smallint;   { Nmero de ports de sada digital }
      nBitsDO     : smallint;   { Nmero de bits por port de sada digital }
    end;

  Const
    cBufSize = 16384;     { Tamanho do buffer em amostras }

  Type {------------------------ Parmetro de sada da WDM_GetAcquiredData --}
    TpUserBuf = array [0..cBufSize-1] of smallint;
    TpAcquiredData = record
      ieStatus: longint;    { Status da aquisio }
      nSamples: longint;    { Nmero de amostras aquisitadas por canal }
      nSampGot: longint;    { Mmero de amostras transferidas por canal }
      iLast   : longint;    { Nmero da ltima amostra transferida para o }
                            { buffer do usurio }
      UserBuf : TpUserBuf;
    end;


{ ===================================================== }
{ =          Declarao de variveis pblicas         = }
{ ===================================================== }

  Var
    DriverInfo: TpDriverInfo;  { Informaes do driver }


{ ========================================================================== }
{ =                     Primitivas do driver WDM_1256                      = }
{ ========================================================================== }

  {-- Primitivas de controle de acesso e iniciao --}
  Function  WDM_Open: dword; stdcall;
  Procedure WDM_Close; stdcall;
  Function  WDM_DriverInfo (Var DriverInfo: TpDriverInfo): boolean; stdcall;
  Function  WDM_GetVersion (Var VersionHigh, VersionLow: byte): boolean; stdcall;
  Function  WDM_GetAIO_Caps (Var TmrClock: single; Var nAiChannels, nAoChannels: smallint;
                             Var nAiRange: smallint; Var AiRange: TpAiRange): boolean; stdcall;
  Function  WDM_GetDIO_Caps (Var nDiPorts, nBitsDI, nDoPorts, nBitsDO: smallint): boolean; stdcall;
  {-- Primitivas da aquisio por interrupo --}
  Procedure WDM_Clear_CM; stdcall;
  Function  WDM_Insert_AI_CM (Channel, iRange: byte): dword; stdcall;
  Function  WDM_Insert_DI_CM (Group: byte): dword; stdcall;
  Function  WDM_AcquisitionSetup (SampleFreq: single; Var ErrorCode: dword): dword; stdcall;
  Procedure WDM_StartAcquisition; stdcall;
  Procedure WDM_StopAcquisition; stdcall;
  Function  WDM_GetAcquiredData (Var AcqData: TpAcquiredData): dword; stdcall;
  Function  WDM_GetAcquiredDataVB (Var ieStatus, nSamples, nSampGot, iLast: longint;
                                   Var UserBuf: TpUserBuf): dword; stdcall; 
  {-- Primitivas de E/S analgica --}
  Function  WDM_SetAiRange (iRange: byte): dword; stdcall;
  Function  WDM_ReadAi (Channel: byte; Var Value: smallint): dword; stdcall;
  Function  WDM_WriteAo (Channel: byte; Value: smallint): dword; stdcall;
  {-- Primitivas de E/S digital --}
  Function  WDM_ReadDI (Group: byte; Var Value: word): dword; stdcall;
  Function  WDM_WriteDO (Group: byte; Value: word): dword; stdcall;


{--------------------------  Bloco de Implementao  ------------------------}
Implementation


{ ========================================================================== }
{ =              Primitivas de controle de acesso ao driver                = }
{ ========================================================================== }

{----------------------------------------- Abre o acesso ao drive WDM_1256 --}
Function WDM_Open; stdcall; external 'WDM_1256.DLL';

{--------------------------------------- Fecha o acesso ao driver WDM_1256 --}
Procedure WDM_Close; stdcall; external 'WDM_1256.DLL';

{-------------------------------------------- Obtm informaes do driver  --}
Function WDM_DriverInfo; stdcall; external 'WDM_1256.DLL';

{----------------------------------------------- Obtm a verso do driver ---}
{----------------------------------- Implementado para uso em Visual Basic --}
Function WDM_GetVersion; stdcall; external 'WDM_1256.DLL';

{------------------------------------- Obtm os recursos de E/S analgica ---}
{----------------------------------- Implementado para uso em Visual Basic --}
Function WDM_GetAIO_Caps; stdcall; external 'WDM_1256.DLL';

{--------------------------------------- Obtm os recursos de E/S digital ---}
{----------------------------------- Implementado para uso em Visual Basic --}
Function WDM_GetDIO_Caps; stdcall; external 'WDM_1256.DLL';

{----------------------------------------------- Limpa a memria de canais --}
Procedure WDM_Clear_CM; stdcall; external 'WDM_1256.DLL';

{--------------------------------------- Insere canal na memria de canais --}
Function WDM_Insert_AI_CM; stdcall; external 'WDM_1256.DLL';

{----------------------------- Insere entrada digital na memria de canais --}
Function WDM_Insert_DI_CM; stdcall; external 'WDM_1256.DLL';

{--------------------------------- Preparao da aquisio por interrupo --}
Function WDM_AcquisitionSetup; stdcall; external 'WDM_1256.DLL';

{-------------------------------------- Inicia a aquisio por interrupo --}
Procedure WDM_StartAcquisition; stdcall; external 'WDM_1256.DLL';

{------------------------------------ Finaliza a aquisio por interrupo --}
Procedure WDM_StopAcquisition; stdcall; external 'WDM_1256.DLL';

{---------------------------- Leitura das amostras aquisitadas pelo driver --}
Function WDM_GetAcquiredData; stdcall; external 'WDM_1256.DLL';

{---------------------------- Leitura das amostras aquisitadas pelo driver --}
Function WDM_GetAcquiredDataVB; stdcall; external 'WDM_1256.DLL';

{---------------------------------------------- Programa ganho da CAD12/56 --}
Function WDM_SetAiRange; stdcall; external 'WDM_1256.DLL';

{---------------------------------------- Le entrada analgica da CAD12/56 --}
Function WDM_ReadAi; stdcall; external 'WDM_1256.DLL';

{---------------------------------- Escreve em sada analgica da CAD12/56 --}
Function WDM_WriteAo; stdcall; external 'WDM_1256.DLL';

{------------------------------------------ Le entrada digital da CAD12/56 --}
Function WDM_ReadDI; stdcall; external 'WDM_1256.DLL';

{------------------------------------ Escreve em sada digital da CAD12/56 --}
Function WDM_WriteDO; stdcall; external 'WDM_1256.DLL';


{ ===================================================== }
{ =            Rotina de iniciao do mdulo          = }
{ ===================================================== }

end.

